@@ -1,8 +1,6 @@
-use warnings;
-use strict;
 package Mojolicious::Plugin::Authentication;
 BEGIN {
-  $Mojolicious::Plugin::Authentication::VERSION = '1.13';
+  $Mojolicious::Plugin::Authentication::VERSION = '1.14';
 }
 use Mojo::Base 'Mojolicious::Plugin';
 
@@ -11,26 +9,29 @@ sub register {
 
     $args ||= {};
 
-    die __PACKAGE__, ": missing 'load_user' subroutine ref in parameters\n" unless($args->{load_user} && ref($args->{load_user}) eq 'CODE');
-    die __PACKAGE__, ": missing 'validate_user' subroutine ref in parameters\n" unless($args->{validate_user} && ref($args->{validate_user}) eq 'CODE');
+    die __PACKAGE__, ": missing 'load_user' subroutine ref in parameters\n"
+        unless $args->{load_user} && ref($args->{load_user}) eq 'CODE';
+    die __PACKAGE__, ": missing 'validate_user' subroutine ref in parameters\n"
+        unless $args->{validate_user} && ref($args->{validate_user}) eq 'CODE';
 
-    my $session_key     = $args->{session_key} || 'session';
-    my $our_stash_key   = $args->{stash_key} || '__authentication__'; 
-    my $load_user_f     = $args->{load_user};
-    my $validate_user_f = $args->{validate_user};
+    my $session_key      = $args->{session_key} || 'auth_data';
+    my $our_stash_key    = $args->{stash_key}   || '__authentication__'; 
+    my $load_user_cb     = $args->{load_user};
+    my $validate_user_cb = $args->{validate_user};
 
     $app->routes->add_condition(authenticated => sub {
-        my ($r, $c, $captures, $required) = (@_);
+        my ($r, $c, $captures, $required) = @_;
         return ($required && $c->user_exists) ? 1 : 0;
     });
+
     $app->plugins->add_hook(before_dispatch => sub {
-        my $self    = shift;
-        my $c       = shift;
-        if(my $uid = $c->session($session_key)) {
-            my $user;
-            $c->stash($our_stash_key => { user => $user }) if($uid && ($user = $load_user_f->($c, $uid)));
+        my ($self, $c) = @_;
+        if (my $uid = $c->session($session_key)) {
+            my $user = $load_user_cb->($c, $uid);
+            $c->stash($our_stash_key => { user => $user }) if $user;
         }
     });
+
     $app->helper(user_exists => sub {
         my $c = shift;
         return (
@@ -39,31 +40,29 @@ sub register {
             ) ? 1 : 0;
 
     });
+
     $app->helper(user => sub {
         my $c = shift;
         return ($c->stash($our_stash_key))
             ? $c->stash($our_stash_key)->{user}
             : undef;
     });
+
     $app->helper(logout => sub {
         my $c = shift;
-        delete($c->stash->{$our_stash_key});
-        delete($c->session->{$session_key});
+        delete $c->stash->{$our_stash_key};
+        delete $c->session->{$session_key};
 
     });
-    $app->helper(authenticate => sub {
-        my $c = shift;
-        my $user = shift;
-        my $pass = shift;
 
-        if(my $uid = $validate_user_f->($c, $user, $pass)) {
+    $app->helper(authenticate => sub {
+        my ($c, $user, $pass) = @_;
+        if (my $uid = $validate_user_cb->($c, $user, $pass)) {
             $c->session($session_key => $uid);
-            $c->session->{$session_key} = $uid;
-            $c->stash->{$our_stash_key}->{user} = $load_user_f->($c, $uid);
+            $c->stash->{$our_stash_key}->{user} = $load_user_cb->($c, $uid);
             return 1;
-        } else {
-            return 0;
         }
+        return;
     });
 }
 
@@ -75,7 +74,7 @@ Mojolicious::Plugin::Authentication - A plugin to make authentication a bit easi
 
 =head1 VERSION
 
-version 1.13
+version 1.14
 
 =head1 SYNOPSIS
 
@@ -87,7 +86,7 @@ version 1.13
         'validate_user' => sub { ... },
     });
 
-    if($self->authenticate('username', 'password')) {
+    if ($self->authenticate('username', 'password')) {
         ... 
     }
 
@@ -96,43 +95,41 @@ version 1.13
 
 =head2 authenticate($username, $password)
 
-    Authenticate will use the supplied load_user and validate_user subroutine refs to see whether a user exists with the given username and password, and will set up the session accordingly.
-    Returns true when the user has been successfully authenticated, false otherwise.
+Authenticate will use the supplied load_user and validate_user subroutine refs to see whether a user exists with the given username and password, and will set up the session accordingly.
+Returns true when the user has been successfully authenticated, false otherwise.
 
 =head2 user_exists
 
-    Returns true if an authenticated user exists, false otherwise.
+Returns true if an authenticated user exists, false otherwise.
 
 =head2 user
 
-    Returns the user object as it was returned from the supplied 'load_user' subroutine ref.
+Returns the user object as it was returned from the supplied 'load_user' subroutine ref.
 
 =head2 logout
 
-    Removes the session data for authentication, and effectively logs a user out.
+Removes the session data for authentication, and effectively logs a user out.
 
 =head1 CONFIGURATION
 
 The following options can be set for the plugin:
 
-    load_user       (REQUIRED)  A coderef for user loading (see USER LOADING)
-    validate_user   (REQUIRED)  A coderef for user validation (see USER VALIDATION)
-    session_key     (optional)  The name of the session key
+load_user       (REQUIRED)  A coderef for user loading (see USER LOADING)
+validate_user   (REQUIRED)  A coderef for user validation (see USER VALIDATION)
+session_key     (optional)  The name of the session key
 
 In order to set the session expiry time, use the following in your startup routine:
 
-    $app->plugin('authentication', { ... });
-    $app->sessions->default_expiration(86400); # set expiry to 1 day
-    $app->sessions->default_expiration(3600); # set expiry to 1 hour
-
+$app->plugin('authentication', { ... });
+$app->sessions->default_expiration(86400); # set expiry to 1 day
+$app->sessions->default_expiration(3600); # set expiry to 1 hour
 
 =head1 USER LOADING
 
 The coderef you pass to the load_user configuration key has the following signature:
 
     sub { 
-        my $app = shift; 
-        my $uid = shift
+        my ($app, $uid) = @_;
         ...
         return $user;
     }
@@ -145,9 +142,7 @@ either a user object (it can be a hashref, arrayref, or a blessed object) or und
 User validation is what happens when we need to authenticate someone. The coderef you pass to the validate_user configuration key has the following signatre:
 
     sub {
-        my $app = shift;
-        my $username = shift;
-        my $password = shift;
+        my ($app, $username, $password) = @_;
         ...
         return $uid;
     }
@@ -222,7 +217,11 @@ L<http://search.cpan.org/dist/Mojolicious-Plugin-Authentication/>
 
 =head1 ACKNOWLEDGEMENTS
 
-Andrew Parker   -   For pointing out some bugs that crept in; a silent reminder not to code while sleepy
+Andrew Parker   
+    -   For pointing out some bugs that crept in; a silent reminder not to code while sleepy
+
+Mirko Westermeier (memowe) 
+    -   For doing some (much needed) code cleanup
 
 =head1 LICENSE AND COPYRIGHT
 
